//----------------------------------------------------------------------
// Titel     : DSP Heimradio Globals include file
//----------------------------------------------------------------------
// Dateiname : globals.h
// Includes  : -
// Hinweis   : globals.h den source Files hinzuf.
//----------------------------------------------------------------------
// Datum     : 22.03.2014 11:22:33
// Version   : 1.01
// Autor     : Andreas Nestler
// Changes   :
//		v1   : initial version; globals functions
//      v1.01: macro NELEMS added
//      v1.02: cleanup, no other header files nested into this header
//----------------------------------------------------------------------

#ifndef __GLOBALS_H__  /* Header wrapper to avoid multiple inclusion */
#define __GLOBALS_H__

/* Some Debugging level definitions */
//#define _DEBUG_RSQ_RSSI_GPO // for debugging only -> set GPO for 1ms * rsq.rssi to high
/* Define Debug level */
// _DEBUG undefined or 0: no extra data written into EEPROM (e.g. RSSI, SNR etc)
// _DEBUG == 1: RSSI, SNR, STBLEND data written in EEPROM
// _DEBUG == 2: as _DEBUG 1 and additional vars
// Hint: DEBUG seems already a defined system var, therefore _DEBUG
#define _DEBUG 0  // debug level 0 - no data written in EEPROM
//#define DISPLAY_SUPPORT // enable I2C OLED display (128 x 64) support

/* definition when RSQ data needed */
#if defined DISPLAY_SUPPORT || _DEBUG > 0 || defined _DEBUG_RSQ_RSSI_GPO
#define READ_RSQ_DATA
#endif

#define DISPLAY_REFRESH_CYC 20U // No of program cycles before display update


#ifndef F_CPU         /* req for delay function */
#define F_CPU 1000000UL  /* CPU frequency -> check fuse settings */
#endif 

/* Hardware IO abstraction macros */

/* Button abstraction */
#define BUTTON_PUSHED (!(PINB & (1<<PINB1))) // !, da Taster an PB1 nach GND
/* Bit Manipulation */
#define SETBIT(VAR, BIT) ((VAR) |= (1 << (BIT))) // set bit
#define CLEARBIT(VAR, BIT) ((VAR) &= (unsigned)~(1 << (BIT))) // clear bit
#define TOGGLEBIT(VAR, BIT) ((VAR) ^= (1 << (BIT))) // Toogle Bit
#define CHECKBIT(VAR, BIT) ((VAR) & (1 << (BIT))) // Check if Bit is set

/* own type definitions */
// typedef unsigned char	u8;
// typedef signed short	s16;


/* Defines for comfort */
#define NELEMS(x)  ((sizeof(x)) / (sizeof(x[0]))) // determines the number of elements of an array

/* Defines to avoid compiler warnings */
#define UNUSED(x) ((void)(x))
// Doppel-Cast, um compiler warning zu vermeiden:
// 'cast to pointer from integer of different size'
#define PUINTCAST(x) ((unsigned int *)(uintptr_t) (x))

#endif


